Struct Theme
pub struct Theme {Show 29 fields
pub name: String,
pub background: Container,
pub primary: Container,
pub secondary: Container,
pub accent: Component,
pub success: Component,
pub destructive: Component,
pub warning: Component,
pub accent_button: Component,
pub success_button: Component,
pub destructive_button: Component,
pub warning_button: Component,
pub icon_button: Component,
pub link_button: Component,
pub text_button: Component,
pub button: Component,
pub palette: CosmicPaletteInner,
pub spacing: Spacing,
pub corner_radii: CornerRadii,
pub is_dark: bool,
pub is_high_contrast: bool,
pub gaps: (u32, u32),
pub active_hint: u32,
pub window_hint: Option<Rgb>,
pub is_frosted: bool,
pub shade: Alpha<Rgb, f32>,
pub accent_text: Option<Alpha<Rgb, f32>>,
pub control_tint: Option<Rgb>,
pub text_tint: Option<Rgb>,
}Expand description
Cosmic Theme data structure with all colors and its name
Fields
name: Stringname of the theme
background: Containerbackground element colors
primary: Containerprimary element colors
secondary: Containersecondary element colors
accent: Componentaccent element colors
success: Componentsuggested element colors
destructive: Componentdestructive element colors
warning: Componentwarning element colors
accent button element colors
suggested button element colors
destructive button element colors
warning button element colors
icon button element colors
link button element colors
text button element colors
button component styling
palette: CosmicPaletteInnerpalette
spacing: Spacingspacing
corner_radii: CornerRadiicorner radii
is_dark: boolis dark
is_high_contrast: boolis high contrast
gaps: (u32, u32)cosmic-comp window gaps size (outer, inner)
active_hint: u32cosmic-comp active hint window outline width
window_hint: Option<Rgb>cosmic-comp custom window hint color
is_frosted: boolenables blurred transparency
shade: Alpha<Rgb, f32>shade color for dialogs
accent_text: Option<Alpha<Rgb, f32>>accent text colors If None, accent base color is the accent text color.
control_tint: Option<Rgb>control tint color
text_tint: Option<Rgb>text tint color
Implementations
impl Theme
impl Theme
pub fn set_name(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_name( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets Theme::name and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_background(
&mut self,
config: &Config,
value: Container,
) -> Result<bool, Error>
pub fn set_background( &mut self, config: &Config, value: Container, ) -> Result<bool, Error>
Sets Theme::background and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_primary(
&mut self,
config: &Config,
value: Container,
) -> Result<bool, Error>
pub fn set_primary( &mut self, config: &Config, value: Container, ) -> Result<bool, Error>
Sets Theme::primary and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_secondary(
&mut self,
config: &Config,
value: Container,
) -> Result<bool, Error>
pub fn set_secondary( &mut self, config: &Config, value: Container, ) -> Result<bool, Error>
Sets Theme::secondary and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_accent(
&mut self,
config: &Config,
value: Component,
) -> Result<bool, Error>
pub fn set_accent( &mut self, config: &Config, value: Component, ) -> Result<bool, Error>
Sets Theme::accent and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_success(
&mut self,
config: &Config,
value: Component,
) -> Result<bool, Error>
pub fn set_success( &mut self, config: &Config, value: Component, ) -> Result<bool, Error>
Sets Theme::success and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_destructive(
&mut self,
config: &Config,
value: Component,
) -> Result<bool, Error>
pub fn set_destructive( &mut self, config: &Config, value: Component, ) -> Result<bool, Error>
Sets Theme::destructive and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_warning(
&mut self,
config: &Config,
value: Component,
) -> Result<bool, Error>
pub fn set_warning( &mut self, config: &Config, value: Component, ) -> Result<bool, Error>
Sets Theme::warning and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::accent_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::success_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::destructive_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::warning_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::icon_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::link_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::text_button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets Theme::button and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_palette(
&mut self,
config: &Config,
value: CosmicPaletteInner,
) -> Result<bool, Error>
pub fn set_palette( &mut self, config: &Config, value: CosmicPaletteInner, ) -> Result<bool, Error>
Sets Theme::palette and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_spacing(
&mut self,
config: &Config,
value: Spacing,
) -> Result<bool, Error>
pub fn set_spacing( &mut self, config: &Config, value: Spacing, ) -> Result<bool, Error>
Sets Theme::spacing and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_corner_radii(
&mut self,
config: &Config,
value: CornerRadii,
) -> Result<bool, Error>
pub fn set_corner_radii( &mut self, config: &Config, value: CornerRadii, ) -> Result<bool, Error>
Sets Theme::corner_radii and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_is_dark(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_is_dark( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets Theme::is_dark and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_is_high_contrast(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_is_high_contrast( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets Theme::is_high_contrast and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_gaps(
&mut self,
config: &Config,
value: (u32, u32),
) -> Result<bool, Error>
pub fn set_gaps( &mut self, config: &Config, value: (u32, u32), ) -> Result<bool, Error>
Sets Theme::gaps and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_active_hint(
&mut self,
config: &Config,
value: u32,
) -> Result<bool, Error>
pub fn set_active_hint( &mut self, config: &Config, value: u32, ) -> Result<bool, Error>
Sets Theme::active_hint and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_window_hint(
&mut self,
config: &Config,
value: Option<Rgb>,
) -> Result<bool, Error>
pub fn set_window_hint( &mut self, config: &Config, value: Option<Rgb>, ) -> Result<bool, Error>
Sets Theme::window_hint and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_is_frosted(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_is_frosted( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets Theme::is_frosted and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_shade(
&mut self,
config: &Config,
value: Alpha<Rgb, f32>,
) -> Result<bool, Error>
pub fn set_shade( &mut self, config: &Config, value: Alpha<Rgb, f32>, ) -> Result<bool, Error>
Sets Theme::shade and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_accent_text(
&mut self,
config: &Config,
value: Option<Alpha<Rgb, f32>>,
) -> Result<bool, Error>
pub fn set_accent_text( &mut self, config: &Config, value: Option<Alpha<Rgb, f32>>, ) -> Result<bool, Error>
Sets Theme::accent_text and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_control_tint(
&mut self,
config: &Config,
value: Option<Rgb>,
) -> Result<bool, Error>
pub fn set_control_tint( &mut self, config: &Config, value: Option<Rgb>, ) -> Result<bool, Error>
Sets Theme::control_tint and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
pub fn set_text_tint(
&mut self,
config: &Config,
value: Option<Rgb>,
) -> Result<bool, Error>
pub fn set_text_tint( &mut self, config: &Config, value: Option<Rgb>, ) -> Result<bool, Error>
Sets Theme::text_tint and writes to cosmic_config::Config if changed
Returns Ok(true) when the field’s value has changed and was written to disk
impl Theme
impl Theme
pub fn dark_config() -> Result<Config, Error>
pub fn dark_config() -> Result<Config, Error>
Get the config for the current dark theme
pub fn light_config() -> Result<Config, Error>
pub fn light_config() -> Result<Config, Error>
Get the config for the current light theme
pub fn light_default() -> Theme
pub fn light_default() -> Theme
get the built in light theme
pub fn dark_default() -> Theme
pub fn dark_default() -> Theme
get the built in dark theme
pub fn high_contrast_dark_default() -> Theme
pub fn high_contrast_dark_default() -> Theme
get the built in high contrast dark theme
pub fn high_contrast_light_default() -> Theme
pub fn high_contrast_light_default() -> Theme
get the built in high contrast light theme
pub fn to_high_contrast(&self) -> Theme
pub fn to_high_contrast(&self) -> Theme
Convert the theme to a high-contrast variant
pub fn control_10(&self) -> Alpha<Rgb, f32>
pub fn control_10(&self) -> Alpha<Rgb, f32>
get control_3 color
pub fn accent_color(&self) -> Alpha<Rgb, f32>
pub fn accent_color(&self) -> Alpha<Rgb, f32>
get @accent_color
pub fn success_color(&self) -> Alpha<Rgb, f32>
pub fn success_color(&self) -> Alpha<Rgb, f32>
get @success_color
pub fn destructive_color(&self) -> Alpha<Rgb, f32>
pub fn destructive_color(&self) -> Alpha<Rgb, f32>
get @destructive_color
pub fn warning_color(&self) -> Alpha<Rgb, f32>
pub fn warning_color(&self) -> Alpha<Rgb, f32>
get @warning_color
pub fn small_widget_divider(&self) -> Alpha<Rgb, f32>
pub fn small_widget_divider(&self) -> Alpha<Rgb, f32>
get @small_widget_divider
pub fn bg_component_color(&self) -> Alpha<Rgb, f32>
pub fn bg_component_color(&self) -> Alpha<Rgb, f32>
get @bg_component_color
pub fn primary_container_color(&self) -> Alpha<Rgb, f32>
pub fn primary_container_color(&self) -> Alpha<Rgb, f32>
get @primary_container_color
pub fn primary_component_color(&self) -> Alpha<Rgb, f32>
pub fn primary_component_color(&self) -> Alpha<Rgb, f32>
get @primary_component_color
pub fn secondary_container_color(&self) -> Alpha<Rgb, f32>
pub fn secondary_container_color(&self) -> Alpha<Rgb, f32>
get @secondary_container_color
pub fn secondary_component_color(&self) -> Alpha<Rgb, f32>
pub fn secondary_component_color(&self) -> Alpha<Rgb, f32>
get @secondary_component_color
get @button_bg_color
pub fn on_bg_color(&self) -> Alpha<Rgb, f32>
pub fn on_bg_color(&self) -> Alpha<Rgb, f32>
get @on_bg_color
pub fn on_bg_component_color(&self) -> Alpha<Rgb, f32>
pub fn on_bg_component_color(&self) -> Alpha<Rgb, f32>
get @on_bg_component_color
pub fn on_primary_container_color(&self) -> Alpha<Rgb, f32>
pub fn on_primary_container_color(&self) -> Alpha<Rgb, f32>
get @on_primary_color
pub fn on_primary_component_color(&self) -> Alpha<Rgb, f32>
pub fn on_primary_component_color(&self) -> Alpha<Rgb, f32>
get @on_primary_component_color
pub fn on_secondary_container_color(&self) -> Alpha<Rgb, f32>
pub fn on_secondary_container_color(&self) -> Alpha<Rgb, f32>
get @on_secondary_color
pub fn on_secondary_component_color(&self) -> Alpha<Rgb, f32>
pub fn on_secondary_component_color(&self) -> Alpha<Rgb, f32>
get @on_secondary_component_color
pub fn accent_text_color(&self) -> Alpha<Rgb, f32>
pub fn accent_text_color(&self) -> Alpha<Rgb, f32>
get @accent_text_color
pub fn success_text_color(&self) -> Alpha<Rgb, f32>
pub fn success_text_color(&self) -> Alpha<Rgb, f32>
get @success_text_color
pub fn warning_text_color(&self) -> Alpha<Rgb, f32>
pub fn warning_text_color(&self) -> Alpha<Rgb, f32>
get @warning_text_color
pub fn destructive_text_color(&self) -> Alpha<Rgb, f32>
pub fn destructive_text_color(&self) -> Alpha<Rgb, f32>
get @destructive_text_color
pub fn on_accent_color(&self) -> Alpha<Rgb, f32>
pub fn on_accent_color(&self) -> Alpha<Rgb, f32>
get @on_accent_color
pub fn on_success_color(&self) -> Alpha<Rgb, f32>
pub fn on_success_color(&self) -> Alpha<Rgb, f32>
get @on_success_color
pub fn on_warning_color(&self) -> Alpha<Rgb, f32>
pub fn on_warning_color(&self) -> Alpha<Rgb, f32>
get @on_warning_color
pub fn on_destructive_color(&self) -> Alpha<Rgb, f32>
pub fn on_destructive_color(&self) -> Alpha<Rgb, f32>
get @on_destructive_color
get @button_color
pub fn bg_divider(&self) -> Alpha<Rgb, f32>
pub fn bg_divider(&self) -> Alpha<Rgb, f32>
get @bg_divider
pub fn bg_component_divider(&self) -> Alpha<Rgb, f32>
pub fn bg_component_divider(&self) -> Alpha<Rgb, f32>
get @bg_component_divider
pub fn primary_container_divider(&self) -> Alpha<Rgb, f32>
pub fn primary_container_divider(&self) -> Alpha<Rgb, f32>
get @primary_container_divider
pub fn primary_component_divider(&self) -> Alpha<Rgb, f32>
pub fn primary_component_divider(&self) -> Alpha<Rgb, f32>
get @primary_component_divider
pub fn secondary_container_divider(&self) -> Alpha<Rgb, f32>
pub fn secondary_container_divider(&self) -> Alpha<Rgb, f32>
get @secondary_container_divider
get @button_divider
pub fn window_header_bg(&self) -> Alpha<Rgb, f32>
pub fn window_header_bg(&self) -> Alpha<Rgb, f32>
get @window_header_bg
pub fn space_none(&self) -> u16
pub fn space_none(&self) -> u16
get @space_none
pub fn space_xxxs(&self) -> u16
pub fn space_xxxs(&self) -> u16
get @space_xxxs
pub fn space_xxxl(&self) -> u16
pub fn space_xxxl(&self) -> u16
get @space_xxxl
pub fn shade_color(&self) -> Alpha<Rgb, f32>
pub fn shade_color(&self) -> Alpha<Rgb, f32>
get @shade_color
pub fn get_active() -> Result<Theme, (Vec<Error>, Theme)>
pub fn get_active() -> Result<Theme, (Vec<Error>, Theme)>
Get the active theme based on the current theme mode.
pub fn with_accent(&self, c: Alpha<Rgb, f32>) -> Theme
pub fn with_accent(&self, c: Alpha<Rgb, f32>) -> Theme
Rebuild the current theme with the provided accent
pub fn gtk_prefer_colorscheme() -> Theme
pub fn gtk_prefer_colorscheme() -> Theme
choose default color palette based on preferred GTK color scheme
pub fn preferred_theme() -> Theme
pub fn preferred_theme() -> Theme
check current desktop environment and preferred color scheme and set it as default
impl Theme
impl Theme
pub fn write_gtk4(&self) -> Result<(), OutputError>
pub fn write_gtk4(&self) -> Result<(), OutputError>
write the CSS to the appropriate directory Should be written in the XDG config directory for gtk-4.0
Errors
Returns an OutputError if there is an error writing the CSS file.
impl Theme
impl Theme
pub fn as_qpalette(&self) -> String
pub fn as_qpalette(&self) -> String
Produces a QPalette ini file for qt5ct and qt6ct.
Example file: https://github.com/trialuser02/qt6ct/blob/master/colors/airy.conf
pub fn write_qt56ct(&self) -> Result<(), OutputError>
pub fn write_qt56ct(&self) -> Result<(), OutputError>
Writes the QPalette ini files to:
~/.config/qt6ct/colors/~/.config/qt5ct/colors/
pub fn apply_qt56ct(is_dark: bool) -> Result<(), OutputError>
pub fn apply_qt56ct(is_dark: bool) -> Result<(), OutputError>
Edits qt{5,6}ct.conf to use COSMIC styles if needed.
pub fn reset_qt56ct() -> Result<(), OutputError>
pub fn reset_qt56ct() -> Result<(), OutputError>
Reset the applied qt56ct config by removing COSMIC-specific entries from the config file.
impl Theme
impl Theme
pub fn as_kcolorscheme(&self) -> String
pub fn as_kcolorscheme(&self) -> String
Produces a color scheme ini file for Qt.
Some high-level documentation for this file can be found at:
- https://api.kde.org/kcolorscheme.html
- https://web.archive.org/web/20250402234329/https://docs.kde.org/stable5/en/plasma-workspace/kcontrol/colors/
pub fn write_qt(&self) -> Result<(), OutputError>
pub fn write_qt(&self) -> Result<(), OutputError>
Write the color scheme to the appropriate directory.
Should be written in ~/.local/share/color-schemes/.
See the docs: https://develop.kde.org/docs/plasma/#color-scheme
Errors
Returns an OutputError if there is an error writing the colors file.
impl Theme
impl Theme
pub fn apply_vs_code(self) -> Result<(), OutputError>
pub fn reset_vs_code() -> Result<(), OutputError>
impl Theme
impl Theme
pub fn apply_exports(&self) -> Result<(), OutputError>
pub fn apply_exports(&self) -> Result<(), OutputError>
Apply COSMIC theme exports for GTK and Qt applications.
pub fn write_exports(&self) -> Result<(), OutputError>
pub fn write_exports(&self) -> Result<(), OutputError>
Write COSMIC theme exports for GTK and Qt applications.
pub fn reset_exports() -> Result<(), OutputError>
pub fn reset_exports() -> Result<(), OutputError>
Un-export GTK and Qt theme configurations applied by us.